Shape inference for graph ops.
Given an OpKind and input shapes, computes the output shape. This is used
by the graph builder to set TensorMeta on newly created nodes.
Enums
- Shape
Error - Error returned when shapes are incompatible for an op.
Functions
- infer_
shape - Infer the output shape for a given op and input shapes.